import { deviceFetch, baseFetch } from '../../api/fetch';

function findMaxIndex(list, key) {
  if (!list.length) return -1;
  let max = list[0][key];
  let maxIndex = 0;
  for (let index = 0; index < list.length; index++) {
    const element = list[index];
    if (element >= max) maxIndex = index;
  }
  return maxIndex;
}
Page({
  /**
   * 页面的初始数据
   */
  data: {
    areaCount: 0,
    year: '',
    dataList: [],
    chargeArr: [],
    recordArr: [],
    operators:[],
    selected: {
      areaId: undefined,
      areaName: '',
      month: '',
      totalMoney: 0,
    },
    total:0,
    timeType: 0,
    pageNum:1,
    pageSize:10
  },
 onLoad: function (options) {
    this.fetchList();
  },
  onPullDownRefresh(){
    if(this.data.timeType==0){
      wx.showLoading({title:'刷新中...'});
      this.fetchList();
      setTimeout(()=>{
        wx.hideLoading();
        wx.stopPullDownRefresh();
      },1500);
    }else{
      wx.stopPullDownRefresh();
    }
  },
  onReachBottom(){
    if(this.data.timeType!=0){
        if(this.data.timeType==1){
          if(this.data.chargeArr.length==this.data.total){
            wx.showToast({
              title:'列表已加载完',
              icon:'none'
            })
            return;
          }else{
            let pageNum = this.data.pageNum;
            this.getRechargeList({
              pageNum: pageNum+1,
              pageSize: this.data.pageSize
            })
          }
        }else{
          console.log(this.data.recordArr.length,this.data.total)
          if(this.data.recordArr.length==this.data.total){
            wx.showToast({
              title:'列表已加载完',
              icon:'none'
            })
            return;
          }else{
            let pageNum = this.data.pageNum;
            this.getRecordList({
              pageNum: pageNum+1,
              pageSize: this.data.pageSize
            })
          }
      }
    }
  },
  toCharge(v){
    let item = v.target.dataset.item;
    wx.navigateTo({
      url:'/pages/recharge/recharge?operatorName='+item.operatorName+"&operatorId="+item.operatorId+"&money="+item.todayMoney,
      events:{
        acceptDataFromOpenedPage: (data)=> {
          this.fetchList();
        },
      }
    })
  },
  toDetail(v){
    let type = v.target.dataset.type;
    let num = v.target.dataset.num;
    let id = v.target.dataset.opid;
    let opName = v.target.dataset.opname;
    if(num==0){
      return;
    }
    wx.navigateTo({
      url:'/pages/deviceDetail/deviceDetail?type='+type+"&operatorId="+id+"&opName="+opName
    })
  },
  changeTimeType(e) {
    const { timetype } = e.currentTarget.dataset;
    if (timetype === this.data.timeType) return;
    this.setData!({
      timeType: timetype,
    });
    //是否需要请求啥
    if (timetype == 1) {
      let list = this.data.chargeArr;
      list.splice(0);
      this.getRechargeList({
        chargeArr:list,
        pageNum: 1,
        pageSize: this.data.pageSize
      });
    } else if (timetype == 2) {
      let list = this.data.recordArr;
      list.splice(0);
      this.getRecordList({
        recordArr:list,
        pageNum: 1,
        pageSize: this.data.pageSize
      })
    }
  },
  getRecordList(entity) {
    baseFetch({
      url: '/v3/operate/balance/page/charging',
      method:'POST',
      data: entity
    }).then(res => {
      res = res.data;
      let total = 0;
      var arr = this.data.recordArr;
      if(res.list&&res.list.length>0){
        res.list.forEach(item=>{
          item.amountt = (item.amount+item.giveAmount).toFixed(2)
          arr.push(item)
        });
      }
      total = res.total;
      this.setData!({
        recordArr:arr,
        total:total,
        pageNum:res.pageNum
      })
    })
  },
  getRechargeList(entity) {
    baseFetch({
      url: '/v3/operate/balance/page/recharge',
      method:'POST',
      data: entity
    }).then(res => {
      res = res.data;
      var arr = this.data.chargeArr;
      if(res.list&&res.list.length>0){
        res.list.forEach(item=>{
          item.amountt = (item.amount+item.giveAmount).toFixed(2)
          arr.push(item)
        });
      }
      let total = res.total;
      this.setData!({
        chargeArr:arr,
        total:total,
        pageNum:res.pageNum
      })
    });
  },
  fetchList() {
    return deviceFetch({
      url: '/deviceServiceFees/operators/balances',
      method:'GET'
    })
      .then(res => {
        res = res.data;
        let opers = this.data.operators;
        opers.splice(0)
        if(res){
          res.forEach(item=>{
            item.amountt = (item.balance + item.giveBalance).toFixed(2)
            opers.push(item);
          })
        }
        this.setData({
          operators:opers
        })
      })
      .catch(err => {
        console.log(err);
      });
  },
  yearChangeHandle(e) {
    console.log(e);
    const { value } = e.detail;
    this.fetchList({
      year: value,
    });
  },
  goRecordPage() {
    wx.navigateTo({
      url: '/pages/platformFeeRecord/platformFeeRecord',
    });
  },
  selectedData(e) {
    console.log(e)
    const data = e.detail;
    this.setData!({
      selected: data,
    });
  },
});
